﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinToolbars;

namespace ToolbarsManagerCustomShortcuts
{
	public partial class Form1 : Form
	{
		private Dictionary<String, String> customShortcuts;  // we'll use this to store the custom shortcuts

		public Form1()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			customShortcuts = new Dictionary<string, string>();

			customShortcuts.Add("ButtonTool4", "Win+A");

			ultraToolbarsManager1.CreationFilter = new CustomShortcutCreationFilter(customShortcuts);
		}
	}

	class CustomShortcutCreationFilter : IUIElementCreationFilter
	{
		private Dictionary<String, String> customShortcuts;

		public CustomShortcutCreationFilter(Dictionary<String, String> customShortcuts)
		{
			this.customShortcuts = customShortcuts;
		}

		#region IUIElementCreationFilter Members

		public void AfterCreateChildElements(UIElement parent)
		{
			if (parent is PopupMenuItemUIElement)
			{
				var menuItem = (parent as PopupMenuItemUIElement).GetContext(typeof(ButtonTool)) as ButtonTool;

				if (customShortcuts.ContainsKey(menuItem.Key))
				{
					if (parent.ChildElements.Count == 1)
					{
						Debug.WriteLine(menuItem.Key + " must have a ShortCut assigned in order for this creation filter to show the custom shortcut.");
						return;
					}
					string shortcut = customShortcuts[menuItem.Key];

					var element = parent.ChildElements[1] as TextUIElement;
					element.Text = shortcut;
					parent.Invalidate();
				}
			}
		}

		public bool BeforeCreateChildElements(UIElement parent)
		{
			return false;
		}

		#endregion
	}
}